//
//  STImageView.m
//  TestSTLivenessController
//
//  Created by sluin on 16/3/29.
//  Copyright © 2016年 SunLin. All rights reserved.
//

#import "STImageView.h"

@interface STImageView () {
    CGFloat _fImageItemWidth;
    CGFloat _fImageItemHeight;
}
@property (strong, nonatomic) UILabel *numberLabel;

@property (strong, nonatomic) UIButton *backButton;

@property (strong, nonatomic) UIImageView *imageView;

@property (strong, nonatomic) UIScrollView *scrollView;

@property (strong, nonatomic) UIImageView *lastSelectImageView;

@end

@implementation STImageView

- (instancetype)init {
    [self doesNotRecognizeSelector:_cmd];
    return nil;
}

- (instancetype)initWithFrame:(CGRect)frame {
    self = [super initWithFrame:frame];

    if (self) {
        self.userInteractionEnabled = YES;

        self.backgroundColor = [UIColor blackColor];

        _fImageItemWidth = (CGRectGetWidth(frame) - 7.0 * 5.0) / 4.0;
        _fImageItemHeight = _fImageItemWidth / 3.0 * 4.0;

        [self addSubview:self.numberLabel];
        [self addSubview:self.backButton];
        [self addSubview:self.imageView];
        [self addSubview:self.scrollView];
    }

    return self;
}

- (UILabel *)numberLabel {
    if (!_numberLabel) {
        _numberLabel = [[UILabel alloc] initWithFrame:CGRectMake(0, 0, CGRectGetWidth(self.frame), 60.0)];
        [_numberLabel setBackgroundColor:[UIColor clearColor]];
        _numberLabel.center = CGPointMake(CGRectGetWidth(self.frame) / 2.0, 30.0);
        _numberLabel.textColor = [UIColor whiteColor];
        _numberLabel.textAlignment = NSTextAlignmentCenter;
    }

    return _numberLabel;
}

- (UIButton *)backButton {
    if (!_backButton) {
        _backButton = [UIButton buttonWithType:UIButtonTypeCustom];
        [_backButton setFrame:CGRectMake(0, 0, 74.0, 60.0)];
        [_backButton setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
        [_backButton setTitle:@"返回" forState:UIControlStateNormal];
        [_backButton setBackgroundColor:[UIColor blackColor]];
        [_backButton addTarget:self action:@selector(onbackButton) forControlEvents:UIControlEventTouchUpInside];
    }

    return _backButton;
}

- (UIImageView *)imageView {
    if (!_imageView) {
        _imageView = [[UIImageView alloc]
            initWithFrame:CGRectMake(0,
                                     60.0,
                                     CGRectGetWidth(self.frame),
                                     CGRectGetHeight(self.frame) - 60.0 - 11.0 * 2.0 - _fImageItemHeight)];
        _imageView.contentMode = UIViewContentModeScaleAspectFit;
    }

    return _imageView;
}

- (UIScrollView *)scrollView {
    if (!_scrollView) {
        _scrollView =
            [[UIScrollView alloc] initWithFrame:CGRectMake(0,
                                                           CGRectGetHeight(self.frame) - 11.0 - _fImageItemHeight,
                                                           CGRectGetWidth(self.frame),
                                                           _fImageItemHeight + 2.0 * 11.0)];
        _scrollView.backgroundColor = [UIColor blackColor];
        _scrollView.showsHorizontalScrollIndicator = NO;
        _scrollView.showsVerticalScrollIndicator = NO;
    }

    return _scrollView;
}

- (void)onbackButton {
    self.hidden = YES;
}

- (void)setImages:(NSArray *)arrImages {
    for (UIImageView *imageView in self.scrollView.subviews) {
        [imageView removeFromSuperview];
    }

    self.scrollView.contentSize =
        CGSizeMake(arrImages.count * _fImageItemWidth + (arrImages.count + 1) * 7.0, _fImageItemHeight + 11.0 * 2.0);

    for (int i = 0; i < arrImages.count; i++) {
        UIImageView *imageView = [[UIImageView alloc]
            initWithFrame:CGRectMake(i * (7.0 + _fImageItemWidth) + 7.0, 11.0, _fImageItemWidth, _fImageItemHeight)];

        imageView.contentMode = UIViewContentModeScaleToFill;
        imageView.clipsToBounds = YES;
        imageView.image = arrImages[i];
        imageView.tag = i + 1000;

        UITapGestureRecognizer *tap =
            [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(onImageViewTap:)];
        [imageView addGestureRecognizer:tap];

        imageView.userInteractionEnabled = YES;

        [self.scrollView addSubview:imageView];

        if (i == 0) {
            imageView.layer.borderWidth = 2;
            imageView.layer.borderColor = [UIColor whiteColor].CGColor;
            self.lastSelectImageView = imageView;
        }
    }

    if (arrImages.count) {
        self.imageView.image = arrImages[0];
        self.numberLabel.text = [NSString stringWithFormat:@"1/%d", (int) arrImages.count];
    }
}

- (void)onImageViewTap:(UITapGestureRecognizer *)tap {
    UIImageView *imageView = ((UIImageView *) tap.view);

    if (imageView.tag == self.lastSelectImageView.tag) {
        return;
    }

    imageView.layer.borderWidth = 2.0;
    imageView.layer.borderColor = [UIColor whiteColor].CGColor;

    self.lastSelectImageView.layer.borderWidth = 0;

    self.lastSelectImageView = imageView;
    self.imageView.image = imageView.image;
    self.numberLabel.text =
        [NSString stringWithFormat:@"%d/%d", (int) imageView.tag - 1000 + 1, (int) self.scrollView.subviews.count];
}

/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect {
    // Drawing code
}
*/

@end
