//
//  FaceDetectingViewController.m
//  CertificationDemo
//
//  Created by 张鹤 on 2018/11/29.
//  Copyright © 2018 张鹤. All rights reserved.
//

#import "FaceDetectingViewController.h"
#import "UIViewExt.h"

@interface FaceDetectingViewController ()
{
    UIImageView *_personsImageView;
}
@end

@implementation FaceDetectingViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.navigationItem.title = @"人脸裁剪算法";
    self.view.backgroundColor = [UIColor whiteColor];
    [self setupUI];
    
}
- (void)setupUI{
    
    _personsImageView = [[UIImageView alloc] initWithFrame:CGRectMake(10, 64 + 20, kScreenWidth - 20, 200)];
    [self.view addSubview:_personsImageView];
    _personsImageView.image = [UIImage imageNamed:@"face.jpg"];
    
    UIButton *detectButton = [[UIButton alloc] initWithFrame:CGRectMake(40, CGRectGetMaxY(_personsImageView.frame) + 10, kScreenWidth - 80, 40)];
    [self.view addSubview:detectButton];
    [detectButton setTitle:@"检测人脸" forState:UIControlStateNormal];
    [detectButton setBackgroundColor:[UIColor redColor]];
    [detectButton addTarget:self action:@selector(detectDidClicked) forControlEvents:UIControlEventTouchUpInside];
    
    
    
}
- (void)detectDidClicked{
    [self faceDetectWithImage:[UIImage imageNamed:@"face.jpg"]];

}
#pragma mark - 识别人脸
- (void)faceDetectWithImage:(UIImage *)image {
    // 图像识别能力：可以在CIDetectorAccuracyHigh(较强的处理能力)与CIDetectorAccuracyLow(较弱的处理能力)中选择
    NSDictionary *opts = [NSDictionary dictionaryWithObject:
                          CIDetectorAccuracyHigh forKey:CIDetectorAccuracy];
    // 将图像转换为CIImage
    CIImage *faceImage = [CIImage imageWithCGImage:image.CGImage];
    CIDetector *faceDetector=[CIDetector detectorOfType:CIDetectorTypeFace context:nil options:opts];
    // 识别出人脸数组
    NSArray *features = [faceDetector featuresInImage:faceImage];
    // 得到图片的尺寸
    CGSize inputImageSize = [faceImage extent].size;
    //将image沿y轴对称
    CGAffineTransform transform = CGAffineTransformScale(CGAffineTransformIdentity, 1, -1);
    //将图片上移
    transform = CGAffineTransformTranslate(transform, 0, -inputImageSize.height);
    
    NSMutableArray *faceArray = [[NSMutableArray alloc] init];
    // 取出所有人脸
    for (CIFaceFeature *faceFeature in features){
        //获取人脸的frame
        CGRect faceViewBounds = CGRectApplyAffineTransform(faceFeature.bounds, transform);
        
        // 裁剪人脸
        UIImage *newImage = [UIImage imageWithCGImage:CGImageCreateWithImageInRect([image CGImage], faceViewBounds)];
        [faceArray addObject:newImage];
        
        CGSize viewSize = _personsImageView.bounds.size;
        CGFloat scale = MIN(viewSize.width / inputImageSize.width,
                            viewSize.height / inputImageSize.height);
        CGFloat offsetX = (viewSize.width - inputImageSize.width * scale) / 2;
        CGFloat offsetY = (viewSize.height - inputImageSize.height * scale) / 2;
        // 缩放
        CGAffineTransform scaleTransform = CGAffineTransformMakeScale(scale, scale);
        // 修正
        faceViewBounds = CGRectApplyAffineTransform(faceViewBounds,scaleTransform);
        faceViewBounds.origin.x += offsetX;
        faceViewBounds.origin.y += offsetY;

        //描绘人脸区域
        UIView* faceView = [[UIView alloc] initWithFrame:faceViewBounds];
        faceView.layer.borderWidth = 2;
        faceView.layer.borderColor = [[UIColor redColor] CGColor];
        [_personsImageView addSubview:faceView];
        
        
        
        // 判断是否有左眼位置
        if(faceFeature.hasLeftEyePosition){}
        // 判断是否有右眼位置
        if(faceFeature.hasRightEyePosition){}
        // 判断是否有嘴位置
        if(faceFeature.hasMouthPosition){}
    }
    
    for (int i = 0; i<features.count; i++) {
        UIImage *faceImage = faceArray[i];
        UIImageView *imageView = [[UIImageView alloc] initWithFrame:CGRectMake(5+105*i, CGRectGetMaxY(_personsImageView.frame) + 60, 100, 100)];
 
        [imageView setImage:faceImage];
        imageView.backgroundColor = [UIColor redColor];
        imageView.contentMode = UIViewContentModeScaleAspectFit;
        [self.view addSubview:imageView];
    }
}


@end
